Class: Psych::Nodes::Scalar

Inherits:
Object
  • Object
show all
Defined in:
lib/psych/pure.rb

Instance Attribute Summary collapse

Instance Attribute Details

#sourceObject

The source of the scalar, as it was found in the input. This may be set in order to be reused when dumping the object.



14
15
16
# File 'lib/psych/pure.rb', line 14

def source
  @source
end