Class: Psych::Pure::Emitter::ObjectNode

Inherits:
Node
  • Object
show all
Defined in:
lib/psych/pure.rb

Overview

Represents a generic object that is not matched by any of the other node types.

Instance Attribute Summary collapse

Attributes inherited from Node

#psych_node, #value

Instance Method Summary collapse

Methods inherited from Node

#initialize

Constructor Details

This class inherits a constructor from Psych::Pure::Emitter::Node

Instance Attribute Details

#dirtyObject

Whether or not this object was modified after being loaded. In this case we cannot rely on the source formatting, and need to instead format the value ourselves.



4156
4157
4158
# File 'lib/psych/pure.rb', line 4156

def dirty
  @dirty
end

#tagObject

The explicit tag associated with the object.



4151
4152
4153
# File 'lib/psych/pure.rb', line 4151

def tag
  @tag
end

Instance Method Details

#accept(visitor) ⇒ Object



4158
4159
4160
# File 'lib/psych/pure.rb', line 4158

def accept(visitor)
  visitor.visit_object(self)
end