Class: Psych::Pure::Emitter::StringNode

Inherits:
Node
  • Object
show all
Defined in:
lib/psych/pure.rb

Overview

Represents a string object.

Instance Attribute Summary collapse

Attributes inherited from Node

#psych_node, #value

Instance Method Summary collapse

Methods inherited from Node

#initialize

Constructor Details

This class inherits a constructor from Psych::Pure::Emitter::Node

Instance Attribute Details

#dirtyObject

Whether or not this object was modified after being loaded. In this case we cannot rely on the source formatting, and need to instead format the value ourselves.



4189
4190
4191
# File 'lib/psych/pure.rb', line 4189

def dirty
  @dirty
end

#tagObject

The explicit tag associated with the object.



4184
4185
4186
# File 'lib/psych/pure.rb', line 4184

def tag
  @tag
end

Instance Method Details

#accept(visitor) ⇒ Object



4191
4192
4193
# File 'lib/psych/pure.rb', line 4191

def accept(visitor)
  visitor.visit_string(self)
end