Class: Psych::Nodes::Scalar
- Inherits:
-
Object
- Object
- Psych::Nodes::Scalar
- Defined in:
- lib/psych/pure.rb
Instance Attribute Summary collapse
-
#source ⇒ Object
The source of the scalar, as it was found in the input.
Instance Attribute Details
#source ⇒ Object
The source of the scalar, as it was found in the input. This may be set in order to be reused when dumping the object.
14 15 16 |
# File 'lib/psych/pure.rb', line 14 def source @source end |